package com.huijy.management.mapper;

import java.util.List;
import com.huijy.management.domain.Member;
import org.apache.ibatis.annotations.Param;

/**
 * 会员信息(游客)Mapper接口
 *
 * @author luobo
 * @date 2021-09-12
 */
public interface MemberMapper
{
    /**
     * 查询会员信息(游客)
     *
     * @param memberId 会员信息(游客)主键
     * @return 会员信息(游客)
     */
    public Member selectMemberByMemberId(Long memberId);

    /**
     * 查询会员信息(游客)列表
     *
     * @param member 会员信息(游客)
     * @return 会员信息(游客)集合
     */
    public List<Member> selectMemberList(Member member);

    /**
     * 新增会员信息(游客)
     *
     * @param member 会员信息(游客)
     * @return 结果
     */
    public int insertMember(Member member);

    /**
     * 修改会员信息(游客)
     *
     * @param member 会员信息(游客)
     * @return 结果
     */
    public int updateMember(Member member);

    /**
     * 删除会员信息(游客)
     *
     * @param memberId 会员信息(游客)主键
     * @return 结果
     */
    public int deleteMemberByMemberId(Long memberId);

    /**
     * 批量删除会员信息(游客)
     *
     * @param memberIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMemberByMemberIds(Long[] memberIds);

    /**
     * 根据openId获取会员信息
     * @param openId
     * @return
     */
    Member selectByOpenId(@Param("openId") String openId);
}
